API_COMMANDS = [
    '_getpkgextensionform',
    'abort_transfer_session',
    'accesshash',
    'accountsummary',
    'acctcounts',
    'activate_zone_key',
    'add_override_features_for_user',
    'add_zone_key',
    'adddns',
    'addpkg',
    'addpkgext',
    'addzonerecord',
    'api_token_create',
    'api_token_get_details',
    'api_token_list',
    'api_token_revoke',
    'api_token_update',
    'applist',
    'batch',
    'changepackage',
    'convert_addon_fetch_conversion_details',
    'convert_addon_fetch_domain_details',
    'convert_addon_get_conversion_status',
    'convert_addon_initiate_conversion',
    'convert_addon_list_addon_domains',
    'convert_addon_list_conversions',
    'cors_proxy_get',
    'create_featurelist',
    'create_integration_group',
    'create_integration_link',
    'create_parked_domain_for_user',
    'create_user_session',
    'createacct',
    'deactivate_zone_key',
    'delete_customizations',
    'delete_featurelist',
    'delete_ssl_vhost',
    'delpkgext',
    'disable_dnssec_for_domains',
    'disable_mail_sni',
    'domainuserdata',
    'dumpzone',
    'editpkg',
    'editquota',
    'editzonerecord',
    'emailtrack_search',
    'emailtrack_stats',
    'emailtrack_user_stats',
    'enable_dnssec_for_domains',
    'enable_mail_sni',
    'enqueue_deferred_ssl_installations',
    'enqueue_transfer_item',
    'export_zone_dnskey',
    'export_zone_files',
    'export_zone_key',
    'fetch_ds_records_for_domains',
    'fetch_ssl_certificates_for_fqdns',
    'fetch_ssl_vhosts',
    'fetch_transfer_session_log',
    'fetch_vhost_ssl_components',
    'fetchcrtinfo',
    'fetchsslinfo',
    'forcepasswordchange',
    'generate_mobileconfig',
    'generatessl',
    'get_available_applications',
    'get_available_authentication_providers',
    'get_available_featurelists',
    'get_best_ssldomain_for_service',
    'get_current_users_count',
    'get_disk_usage',
    'get_domain_info',
    'get_feature_metadata',
    'get_feature_names',
    'get_featurelist_data',
    'get_featurelists',
    'get_integration_link_user_config',
    'get_maximum_users',
    'get_nameserver_config',
    'get_password_strength',
    'get_public_contact',
    'get_public_ip',
    'get_remote_access_hash',
    'get_shared_ip',
    'get_transfer_session_state',
    'get_upgrade_opportunities',
    'get_users_authn_linked_accounts',
    'get_users_links',
    'getdomainowner',
    'gethostname',
    'getpkginfo',
    'getresellerips',
    'getzonerecord',
    'has_digest_auth',
    'has_mycnf_for_cpuser',
    'hold_outgoing_email',
    'import_zone_key',
    'installssl',
    'is_sni_supported',
    'killdns',
    'killpkg',
    'limitbw',
    'link_user_authn_provider',
    'list_integration_groups',
    'list_integration_links',
    'list_mysql_databases_and_users',
    'list_styles',
    'list_users',
    'listaccts',
    'listcrts',
    'listmxs',
    'listpkgs',
    'listsuspended',
    'listzones',
    'load_style',
    'lookupnsip',
    'lookupnsips',
    'mail_sni_status',
    'mass_edit_dns_zone',
    'massmodifyacct',
    'matchpkgs',
    'modifyacct',
    'myprivs',
    'nvget',
    'nvset',
    'parse_dns_zone',
    'passwd',
    'pause_transfer_session',
    'read_featurelist',
    'rebuild_mail_sni_config',
    'rebuilduserssldb',
    'release_outgoing_email',
    'remove_integration_group',
    'remove_integration_link',
    'remove_logo',
    'remove_override_features_for_user',
    'remove_style',
    'remove_zone_key',
    'removeacct',
    'removezonerecord',
    'resetzone',
    'resolvedomainname',
    'retrieve_customizations',
    'save_style',
    'savemxs',
    'set_default',
    'set_digest_auth',
    'set_nsec3_for_domains',
    'set_primary_servername',
    'set_public_contact',
    'setresellernameservers',
    'showbw',
    'start_transfer_session',
    'suspend_outgoing_email',
    'suspendacct',
    'systemloadavg',
    'transfer_module_schema',
    'twofactorauth_generate_tfa_config',
    'twofactorauth_get_issuer',
    'twofactorauth_get_user_configs',
    'twofactorauth_policy_status',
    'twofactorauth_remove_user_config',
    'twofactorauth_set_issuer',
    'twofactorauth_set_tfa_config',
    'uapi_cpanel',
    'unlink_user_authn_provider',
    'unset_nsec3_for_domains',
    'unsuspend_outgoing_email',
    'unsuspendacct',
    'update_customizations',
    'update_featurelist',
    'update_integration_link_token',
    'verify_new_username',
    'verify_new_username_for_restore',
    'verify_user_has_feature',
    'version'
]